ascii_fold
A package to convert non-ascii characters into their ascii equivalent, if a
reasonable one exists. For example accents are removed ("à" becomes "a"),
and composite characters are split into their composing letters ("ᴁ" becomes
"AE").
You can add this package to your project by running:
gleam add ascii_fold@1
And use the ascii_fold.fold function:
import ascii_fold
pub fn main() -> Nil {
assert ascii_fold.fold("Hello, Łukasz") == "Hello, Lukasz"
}
This package behaves the same as Apache’s Lucene ascii folding filter.