ascii_fold

Values

pub fn fold(string: String) -> String

Convert non-ascii characters into their ascii equivalent, if a reasonable one exists.

For example accents are removed:

assert ascii_fold.fold("À") == "A"

And composite characters are split into their composing letters:

assert ascii_fold.fold("⁇") == "??"
assert ascii_fold.fold("ᴁ") == "AE"
Search Document